@@ -214,7 +214,7 @@ class RKXMLRequest(XMLRequest):
                     table_code=(order.get('TableCode')), order_categ_id=(order.get('OrderCategId')),
                     order_categ_code=(order.get('OrderCategCode')), bill=(order.get('Bill')),
                     waiter_id=(order.get('WaiterID')), order_type_code=(order.get('OrderTypeCode')),
-                    order_type_id=(order.get('OrderTypeId')), to_pay_sum=(order.get('ToPaySum')),
+                    order_type_id=(order.get('OrderTypeID')), to_pay_sum=(order.get('ToPaySum')),
                     waiter_code=(order.get('WaiterCode')), order_sum=(order.get('OrderSum')),
                     total_pieces=(order.get('TotalPieces')), finished=(order.get('Finished')),
                     price_list_sum=(order.get('PriceListSum')), dessert=(order.get('Dessert')),
