@@ -1,3 +1,5 @@
+from datetime import datetime
+
 from typing import TypedDict
 
 
@@ -12,6 +14,8 @@ class EmployeeDTO(TypedDict):
 
 
 class OrderListDTO(TypedDict):
+    visit_id: int
+    count_guest: int
     order_id: int
     order_name: str
     url: str
@@ -33,6 +37,8 @@ class OrderListDTO(TypedDict):
     finished: int
     bill: int
     dessert: int
+    created_time: datetime
+    finished_time: datetime
 
 
 class WaiterListDTO(TypedDict):
